<?php get_header(); ?>

<div class="container">
	<div class="row">
		<main id="main" class="site-main col-md-8 col-md-offset-2" role="main">
			<?php
				if ( have_posts() ) {
					while ( have_posts() ) { the_post();
						get_template_part( 'content-portfolio', get_post_format() );
					}
				} else {
					get_template_part( 'content', 'none' );
				}
			?>

			<nav class="page-nav">
				<?php 
					$args = array(
						'type'      => 'list',
						'next_text' => '<i class="fa fa-angle-right"></i>',
						'prev_text' => '<i class="fa fa-angle-left"></i>',
					);

					echo paginate_links( $args );
				?>
			</nav>
		</main>
	</div>
</div>

<?php get_footer(); ?>