<?php get_header(); ?>

<?php

if( get_post_type() == 'portfolio' ) {
	if ( have_posts() ) {
		while ( have_posts() ) { the_post();
			get_template_part( 'content-portfolio-single', get_post_format() );
		}
	}
	get_footer();

	return true;
}

?>

<?php get_footer(); ?>