.import-warning {
	color: #B94A48;
	margin-top: 15px !important;
}

.import-action:after {
	clear: both;
	content: "";
	display: table;
}

.import-submit,
.import-load {
	float: left;
}

#gfxbucket-import[disabled] + .import-load {
	display: inline-block;
}

.import-load {
	border: 2px solid rgba(0, 0, 0, 0);
	border-right-color: #ccc;
	border-radius: 100%;
	display: none;
	left: 10px;
	height: 18px;
	position: relative;
	top: 3px;
	width: 18px;
	-webkit-animation: spinner 1s infinite linear;
	animation: spinner 1s infinite linear;
}

@-webkit-keyframes spinner {
  from {
	-webkit-transform: rotate(0deg);
    transform: rotate(0deg); 
  }

  to {
    -webkit-transform: rotate(360deg);
    transform: rotate(360deg); 
  }
}

@keyframes spinner {
  from {
    -webkit-transform: rotate(0deg);
    transform: rotate(0deg);
  }

  to {
    -webkit-transform: rotate(360deg);
    transform: rotate(360deg);
  }
}