<form action="<?php echo esc_url( home_url( '/' ) ); ?>" method="get" data-form="submit" role="search">
	<span class="screen-reader-text"><?php echo _x( 'Search for:', 'dropout' ) ?></span>
	<input name="s" type="text" value="<?php echo get_search_query() ?>" name="s" title="<?php echo esc_attr_x( 'Search for:', 'dropout' ) ?>">
	<button type="submit" class="search-submit"><i class="fa fa-search"></i></button>
</form>