<?php
/**
 * Theme Footer
 */
?>
		<?php Gfxbucket::footer(); ?>
	</div>

	<?php wp_footer(); ?>
</body>
</html>

<script>


	

	jQuery(".panel-row-style-colortalk-home .so-widget-gfxbucket-title h3.section-title").text("Are you ready for your next project?");



	var claseFinal = "";
    var arrayPais = new Array();
	var arrayInd = new Array();

	jQuery("article").attr("data-type","testimonio").each(function(){

		var estePais = jQuery(this).attr("data-pais");
		var estaIndustria = jQuery(this).attr("data-industria");



            if  (estePais!= ""){

                if (jQuery.inArray(estePais, arrayPais) != -1) {
                
                    //echo "Existe esta variable".$ano;
                
                }else{

                 //echo "no existe";
                  arrayPais.push(estePais);
                }
            }

               if  (estaIndustria!= ""){

                if (jQuery.inArray(estaIndustria, arrayInd) != -1) {
                
                    //echo "Existe esta variable".$ano;
                
                }else{

                 //echo "no existe";
                  arrayInd.push(estaIndustria);
                }
            }


            arrayPais.sort();
            arrayInd.sort();

	});



	var optionsIndustria = "";
	var optionsPais = "";

	for(i=0; i < arrayInd.length ; i++){

		optionsIndustria += "<option>"+ arrayInd[i]+"</option>";

	}

	for(i=0; i < arrayPais.length ; i++){

		optionsPais += "<option>"+ arrayPais[i]+"</option>";

	}



	var filterCreator = '<select id="filtroactividad"><option value="0">Actividad</option>'+optionsIndustria+'</select>';

	var filterCreator2 = '<select id="filtroPais"><option value="0">País</option>'+optionsPais+'</select>';

	console.log(arrayInd[0]);

	console.log(arrayPais[0]);

	console.log(filterCreator);


	jQuery("#porIndustriaWp").html(filterCreator);
	jQuery("#porPaisWp").html(filterCreator2);


	if(jQuery("body").hasClass("page-id-209")){


		var listaTestimonios = jQuery(".blog-masonry");
		var paisFlag = false;
		var industriaFlag = false;
		var elementoConClase;
	      
	    listaTestimonios.isotope({
	      itemSelector: ".divContendorArticle",
	   
	    });
	  

	    var palabraActSeleccionada;
	    
    
	    jQuery("#filtroactividad").change(function() {

	    	var selecionado = jQuery("#filtroactividad option:selected").text();

	    	var cantidadPalabras = selecionado.split(' ').length;

	    	if(cantidadPalabras != 1){

	    		palabraActSeleccionada = selecionado.substr(0, selecionado.indexOf(" "));


	    	} else{

	    		var palabraActSeleccionada = selecionado;
	    	}
	    
	    	
	    	

	    	if(palabraActSeleccionada == ".Por"){
	    		palabraActSeleccionada = "*";
	    	}

	    	if(palabraActSeleccionada == ".Medios,"){
	    		palabraActSeleccionada = "Publicidad";
	    	}

	    	 constructClassForFilters(palabraActSeleccionada);
	    	// listaTestimonios.isotope({ filter: palabraActSeleccionada });

	    	 console.log("filtrad: "+claseFinal);



		});

 	   jQuery("#FiltroButton2").click(function(){
 	   		event.preventDefault();

 	   			jQuery("#filtroPais").val('0');
		   	jQuery("#filtroactividad").val('0');
		   	
		  
		    listaTestimonios.isotope({ filter: "*" });
		
		  });

	  


	    function constructClassForFilters(str){

			var dataClass = str;


			claseFinal = claseFinal+"."+dataClass;

		}




	     jQuery("#FiltroButton").click(function(){
	     	event.preventDefault();
	     	var actividadOption = jQuery( "#filtroactividad option:selected" ).text();
		    var paisOption = jQuery( "#filtroPais option:selected" ).text();

	     	var classFinal = "";
		      
		      if(paisOption!="Por país"){

		      	paisOption = "."+paisOption;
		        classFinal += paisOption;

		      }
		  
		      if(actividadOption!="Por industria"){

		      	var cantidadPalabras = actividadOption.split(' ').length;

		    	if(cantidadPalabras != 1){

		    		var palabraAct = actividadOption.substr(0, actividadOption.indexOf(" "));


		    	} else{

		    		var palabraAct = actividadOption;
		    	}
			       
		   
		        palabraAct = "."+palabraAct;
		        classFinal +=palabraAct;

		      }


		      console.log(paisOption);
		      console.log(actividadOption);
		      console.log("esos son los filtros");
		      console.log(classFinal);

		      listaTestimonios.isotope({ filter: classFinal });

		      listaTestimonios.on( 'arrangeComplete',
			  function( event, filteredItems ) {
			    console.log( 'Isotope arrange completed on ' +
			      filteredItems.length + ' items' );
			  }
			);


	    });


	
	}

	if(jQuery("body").hasClass("page-id-323")){
  var notFound = false;


		 var largoObjetosFiltrados ;

		var barraFiltros = jQuery( ".filtrosWp" );
		jQuery( ".filtrosWp" ).remove();

		jQuery( ".page-spacing .site" ).css("padding-top","7.5em");

		jQuery( "#filtrosRowWP" ).append(barraFiltros);


		 jQuery(".filtrosWp").append(jQuery(".fixed-top"));
  		 var filteredFlag = false;
		





	var	elementoAnterior ="";
	var	elementoAnterior2 ="";

	  var listaCasos = jQuery("#rowsCasos");

	      
	    listaCasos.isotope({
	      itemSelector: "tr",
	      layoutMode: "vertical"
	    });
	  

	
		  	 var grid = jQuery(".portfolio-masonry-spacing");
		    
			    grid.isotope({
			      itemSelector: ".portfolio-item",
			      layoutMode: "fitRows"
			    });


			grid.isotope({ filter:  ".pagina1"});
			listaCasos.isotope({ filter:  ".pagina1"});


	   		jQuery(".botonGrilla").click(function(){

    			  event.preventDefault();
    			  
    			  var esteElemento = jQuery(this);

    			  if(elementoAnterior!=""){

    			  	elementoAnterior.removeClass("activeFilterPage");
    			  }

    			  esteElemento.addClass("activeFilterPage");

    			  var filtro = jQuery(this).attr("data-page");



	    		  filtro = "."+filtro;
	    		  pageActual = filtro;

    			  console.log("filtre"+filtro);


    			grid.isotope({ filter:  filtro});

    			elementoAnterior = jQuery(this);



			  
    		});

    		jQuery(".botonTabla").click(function(){

    			  
    			  var esteElemento = jQuery(this);

    			  if(elementoAnterior2!=""){

    			  	elementoAnterior2.removeClass("activeFilterPage");
    			  }

    			  esteElemento.addClass("activeFilterPage");

    			  var filtro = jQuery(this).attr("data-page");


	    		  filtro = "."+filtro;
	    		  pageActual = filtro;

    			  console.log("filtre"+filtro);


    			listaCasos.isotope({ filter:  filtro});

    			elementoAnterior2 = jQuery(this);



			  
    		});


    		


		   jQuery("#FiltroButton2").click(function(){

		   	jQuery("#filtropais").val('0');
		   	jQuery("#filtroactividad").val('0');
		   	jQuery("#filtroano").val('0');

		   	    console.log("Limpie filtre");

		   	      if(notFound){
		      	//jQuery("#resulBusqueda").css("display","none");
		      	
		      	jQuery( "#pg-323-2").css("display","block");
		      	notFound = false;

		      }

		    grid.isotope({ filter: ".pagina1" });
		    listaCasos.isotope({ filter: ".pagina1" });
		    

		
           
            jQuery("#paginadorWp").css("display","block");
            jQuery("#paginadorWp2").css("display","block");

              if(filteredFlag){

		          console.log("aqui2"+elementoConClase);

		           if(largoObjetosFiltrados>1){



			     	    elementoConClase.classList.remove("largeItem");
			          	console.log("removi la clasesss");

		          }
				    			
    		 }
    			






		  });



    jQuery("#FiltroButton").click(function(){

		    console.log("arranco el filtro")  

    		if(filteredFlag){

		          console.log("Elementos"+elementoConClase);

		           if(largoObjetosFiltrados>1){

			     	    elementoConClase.classList.remove("largeItem");
			     	    elementoConClase.classList.remove("largeItemOnGrid");
			          	console.log("removidas la clase");

		          }
				    			
    		 }

		
		      var paisOption = jQuery( "#filtropais option:selected" ).text();
		      var actividadOption = jQuery( "#filtroactividad option:selected" ).text();
		      var anoOption = jQuery( "#filtroano option:selected" ).text();

		      var pageActual = ".pagina1";
		      var classFinal = "";

		      if(notFound){
		      	//jQuery("#resulBusqueda").css("display","none");
		      	jQuery( "#pg-323-2").css("display","block");
		      	notFound = false;

		      }

		      /*
		      if(anoOption!="AÑO"){

		      	anoOption = "."+anoOption;

		        classFinal +=anoOption;

		      }*/

		      if(paisOption!="PAÍS"){

		      	paisOption = "."+paisOption;	
		        classFinal += paisOption;

		      }
		  
		      if(actividadOption!="ACTIVIDAD"){
		       
		        var palabraAct =  actividadOption.split(" ").pop();


		        palabraAct = "."+palabraAct;

		        classFinal += palabraAct;

		      }


		     console.log(classFinal);


		     grid.isotope({ filter: classFinal });
		     listaCasos.isotope({ filter: classFinal });

		     jQuery("#paginadorWp").css("display","none");
		      jQuery("#paginadorWp2").css("display","none");

    		 filteredFlag = true;

		  });


		    var iso = grid.data('isotope');


		     grid.on( 'arrangeComplete',
			  	
			  	function( event, filteredItems ) {

				    console.log( 'Se termino el filtrado ' +  filteredItems.length + ' items');
				     largoObjetosFiltrados = filteredItems.length;

					if(filteredFlag){

				          console.log("Elementosss"+elementoConClase);

				           if(largoObjetosFiltrados>1){

					     	    elementoConClase.classList.remove("largeItem");
					     	    elementoConClase.classList.remove("largeItemOnGrid");
					          	console.log("limpiamos antes de cargar");

				          }
						    			
		    		 }

		    		if(largoObjetosFiltrados == 0){

		    			var paisOption = jQuery( "#filtropais option:selected" ).text();
		     			var actividadOption = jQuery( "#filtroactividad option:selected" ).text();
		     			//var anoOption = jQuery( "#filtroano option:selected" ).text();
		    			
		    			var classResultados = "";

		    			if(paisOption!="PAÍS" && actividadOption!="ACTIVIDAD" ){
		    				var paisSelected = paisOption;
					      	paisOption = "."+paisOption;	
					        classResultados += paisOption;


					     	//jQuery("#resulBusqueda").css("display","block");
					     	//jQuery("#resulBusqueda .filtroSelected").text(paisSelected);

					     	jQuery( "#pg-323-2").css("display","none");

					      /* else if(actividadOption!="ACTIVIDAD"){
		       				
		       				var actividadSelected = actividadOption;
					        var palabraAct = actividadOption.split(" ").pop();

					        palabraAct = "."+palabraAct;
					        classResultados += palabraAct;


					     	//jQuery("#resulBusqueda").css("display","block");
					     	//jQuery("#resulBusqueda .filtroSelected").text(actividadSelected);
					     	jQuery( "#pg-323-2").css("display","none");



					      }*/

					     

					    	 //if(largoObjetosFiltrados == 0)

						     if(notFound){


						     }else{
						     	 grid.isotope({ filter: classResultados });
				   				 listaCasos.isotope({ filter: classResultados });

				   				 notFound = true;
	   				

						     }
				    	
		   				}


				    };


				   
				    if(largoObjetosFiltrados>1){


					    for(i=0; i<largoObjetosFiltrados; i++){

					    	var esteElemento = iso.filteredItems[i].element;

					    	esteElemento.classList.remove("largeItem");
					    	esteElemento.classList.remove("largeItemOnGrid");

					    	if(i==2){

					    		if (notFound == false){
					    			esteElemento.className += "largeItem ";
					    		}else{


					    		}
					    		
					    	};
					       

					       	 elementoConClase = iso.filteredItems[2].element;

					       	 console.log("aqui"+elementoConClase);


					    }

				    } 

			  });


	};

</script>