.mce-content-body * {
	font-family: 'Lato';
}

/* mark */

.mce-content-body mark {
	background-color: #222;
	color: #FFF;
	padding: .1em .2em;
}

.mce-content-body mark.style-2 { background-color: #F7505A; }
.mce-content-body mark.style-3 { background-color: #1FB8B2; }

/* Drop Caps */

.mce-content-body .dropcaps {
	color: #222;
	float: left;
	font-size: 48px;
	font-weight: 900;
	line-height: 1em;
	margin-right: 20px;
}

.mce-content-body .dropcaps.style-2 {
	background-color: #222;
	color: #FFF;
	font-size: 20px;
	height: 34px;
	line-height: 34px;
	margin-right: 10px;
	margin-top: 8px;
	text-align: center;
	width: 34px;
}

/* Blockquotes */

blockquote + blockquote {
	margin-top: 0;
}

blockquote {
	border-left: 5px solid #EEE;
	font-size: inherit;
	margin: 78px 0;
	padding: 10px 20px;
	padding-left: 31px;
}

blockquote.style-2 {
	border: none;
	font-size: 24px;
	padding: 0 20px;
	text-align: center;
}

blockquote.style-3 {
	background-color: #F1F1F1;
	border: none;
	font-style: italic;
	font-size: 21px;
	font-weight: 300;
	padding: 20px 57px 20px 95px;
	position: relative;
}