  	jQuery(function (jQuery) {
    var doAnimations = function () {
        var offset = jQuery(window).scrollTop() + jQuery(window).height(), jQueryanimatables = jQuery('.animatable');
        if (jQueryanimatables.size() == 0) {
            jQuery(window).off('scroll', doAnimations);
        }
        jQueryanimatables.each(function (i) {
            var jQueryanimatable = jQuery(this);
            if (jQueryanimatable.offset().top + jQueryanimatable.height() - 20 < offset) {
                jQueryanimatable.removeClass('animatable').addClass('animated');
            }
        });
    };
    jQuery(window).on('scroll', doAnimations);
    jQuery(window).trigger('scroll');

	});
	jQuery( document ).ready(function() {

		jQuery(".blog-home .blog-posts a.more").text("View more");
		jQuery(".single-post .recent-posts .blog-more").text("Next");		
		jQuery(".blog-clients .blog-posts a.more").text("View more");
		jQuery("footer .instagram h5").text("Follow us");
		jQuery(".widget_search input").attr("placeholder","Search");
		jQuery(".page-cover-content input").attr("placeholder","Type Search");
		
		jQuery(".blog-interior .blog-post-author-details").html(function () {
			return jQuery(this).html().replace("By", "By");
		});
		jQuery(".blog-interior .blog-post-author-details").html(function () {
			return jQuery(this).html().replace("on", "on");
		});
		jQuery(".single-post .blog-post-author-details").html(function () {
			return jQuery(this).html().replace("By", "By");
		});
		jQuery(".single-post .blog-post-author-details").html(function () {
			return jQuery(this).html().replace("on", "on");
		});
		jQuery(".single-post .blog-post-author-details").html(function () {
			return jQuery(this).html().replace("in", "in");
		});
		
		jQuery("h3.portfolio-post-header-heading-small").text("Project Specifications");

		jQuery(".blog-interior .blog-posts a.more").text("View more");
		jQuery(".blog-interior .blog-posts a.blog-post-comments-link").html(function () {
			return jQuery(this).html().replace("comments", "comments");
		});

		jQuery(".portfolio-post-header-meta li").each(function () {
			if (jQuery(this).find("strong").html() == "superficier:")
			{
				jQuery(this).addClass("superficier");
				jQuery(this).find("strong").html(function () {
					return jQuery(this).html().replace("superficier", "Area");
				});
			}else if (jQuery(this).find("strong").html() == "plazo_de_la_obra:")
			{
				jQuery(this).addClass("plazo_de_la_obra");
				jQuery(this).find("strong").html(function () {
					return jQuery(this).html().replace("plazo_de_la_obra", "Term of the work");
				});
			}
			else if (jQuery(this).find("strong").html() == "ubicacion:")
			{
				jQuery(this).addClass("ubicacion");
				jQuery(this).find("strong").html(function () {
					return jQuery(this).html().replace("ubicacion", "Location");
				});
			}
			else if (jQuery(this).find("strong").html() == "proyecto:")
			{
				jQuery(this).addClass("proyecto");
				jQuery(this).find("strong").html(function () {
					return jQuery(this).html().replace("proyecto", "Design");
				});
			}
			else if (jQuery(this).find("strong").html() == "tipo_de_obra:")
			{
				jQuery(this).addClass("tipo_de_obra");
				jQuery(this).find("strong").html(function () {
					return jQuery(this).html().replace("tipo_de_obra", "Type");
				});
			}
			else if (jQuery(this).find("strong").html() == "ano:")
			{
				jQuery(this).addClass("ano");
				jQuery(this).find("strong").html(function () {
					return jQuery(this).html().replace("ano", "Year");
				});
			}
			else if (jQuery(this).find("strong").html() == "pais:")
			{
				jQuery(this).addClass("pais");
				jQuery(this).find("strong").html(function () {
					return jQuery(this).html().replace("pais", "Country");
				});
			}
			else if (jQuery(this).find("strong").html() == "actividad:")
			{
				jQuery(this).addClass("actividad");
				jQuery(this).find("strong").html(function () {
					return jQuery(this).html().replace("actividad", "Activity");
				});
			}
			else if (jQuery(this).find("strong").html() == "link:")
			{
				jQuery(this).addClass("none");
			}
			else if (jQuery(this).find("strong").html() == "subtitulo_de_la_obra:")
			{
				jQuery(this).css("display","none");
				/*jQuery(".portfolio-post-header-heading-small small").html(jQuery(this).html());
				jQuery(this).addClass("none");*/
			}
			else if (jQuery(this).find("strong").html() == "subtitulo_de_la_obra::")
			{
				jQuery(this).css("display","none");
				/*jQuery(".portfolio-post-header-heading-small small").html(jQuery(this).html());
				jQuery(this).addClass("none");*/
			}
			else if (jQuery(this).find("strong").html() == "sin_fotos:")
			{
				jQuery(this).remove();
				/*jQuery(".portfolio-post-header-heading-small small").html(jQuery(this).html());
				jQuery(this).addClass("none");*/
			}



			
		});	

  		if(jQuery(".portfolio-post-header-meta li:nth-child(1)").find("strong").html() == "superficie:"){

  			if(jQuery(".portfolio-post-header-meta li:nth-child(1)").hasClass("superficier")){
  				console.log("tiene la clase superficier");
  			}else{

  				jQuery(".portfolio-post-header-meta li:nth-child(1)").addClass("superficier");
  					console.log("se le puso la clase superficier");
  				jQuery(".portfolio-post-header-meta li:nth-child(1)").html(function () {
					return jQuery(this).html().replace("superficie", "Superficie");
				});
  			}

  	    };

  		if(jQuery(".portfolio-post-header-meta li:nth-child(2)").hasClass("ubicacion")){

  			jQuery(".portfolio-post-header-meta li:nth-child(2)").insertBefore(".portfolio-post-header-meta li:nth-child(5)");
  			console.log("ubicacion segundo");

  		}else{
  			console.log("no la tiene");
  		}


  		if(jQuery(".portfolio-post-header-meta li:nth-child(1)").hasClass("ubicacion")){

  			jQuery(".portfolio-post-header-meta li:nth-child(1)").insertBefore(".portfolio-post-header-meta li:nth-child(4)");
  			console.log("ubicacion segundo");

  		}else{
  			console.log("no la tiene");
  		}


		/*jQuery("footer .social").append('<li><a href="https://plus.google.com/103025594734805624340/posts" target="_blank"><i class="fa fa-google"></i></a></li><li><a href="https://www.instagram.com/contract_workplaces/" target="_blank"><i class="fa fa-instagram"></i></a></li><li><a href="https://es.pinterest.com/contractwp/" target="_blank"><i class="fa fa-pinterest"></i></a></li><li><a href="https://www.youtube.com/user/ContractWorkplaces" target="_blank"><i class="fa fa-youtube"></i></a></li>');*/
		
		/*jQuery(".social-contact .social").append('/*<li><a href="https://plus.google.com/103025594734805624340/posts" target="_blank"><i class="fa fa-google"></i></a></li><li><a href="https://www.instagram.com/contract_workplaces/" target="_blank"><i class="fa fa-instagram"></i></a></li><li><a href="https://es.pinterest.com/contractwp/" target="_blank"><i class="fa fa-pinterest"></i></a></li><li><a href="https://www.youtube.com/user/ContractWorkplaces" target="_blank"><i class="fa fa-youtube"></i></a></li>');*/
		jQuery("footer .social").append('<li class="int_li"><a href="https://www.instagram.com/contract_workplaces/" target="_blank"><i class="fa fa-instagram"></i></a></li>');
		jQuery(".social-contact .social").append('<li><a href="https://www.instagram.com/contract_workplaces/" target="_blank"><i class="fa fa-instagram"></i></a></li>');

		jQuery(".contact-down").click(function() {
			jQuery(".contact-home").slideToggle('slow');
			return false;
		});

		jQuery('form').find("input[name='email-295']").each(function(ev){
		  if(!jQuery(this).val()) { 
			 jQuery(this).attr("placeholder", "Email");
		  }
		});
		jQuery('form').find("input[name='email-295']").click(function(ev){
		  jQuery(this).attr("placeholder", "");
		});
		
		
		jQuery(".filter .equipoBtn").click(function() {
			jQuery(".filter .equipoBtn").removeClass('active');
			jQuery(this).addClass('active');
			return false;
		});		

		if ( document.body.clientWidth <= 977)
		{			
			jQuery(".filter-team").click(function() {
				jQuery(".filter-team div").fadeToggle('slow');
				return false;
			});
			jQuery(".filter-team .equipoBtn").click(function() {
				jQuery(".filter-team div").fadeOut('slow');
				return false;
			});

		}
		/*jQuery(".filter-select #FiltroButton").click(function() {
			alert(jQuery(".filter-select select option:selected").val());
			jQuery("#rowsCasos tr").fadeOut();
			jQuery("#rowsCasos tr")attr("class",jQuery(".filter-select select option:selected").val()).fadeIn();
			return false;
		});*/

		

		jQuery(".chart").each(function() {
			

			jQuery(this).find('.malo_acc .widget-title').append('<small>Bad</small>');

			jQuery(this).find('.malo_acc .widget-title small').first().html('N/A');
			jQuery(this).find('.regular_acc .widget-title').append('<small>Regular</small>');
			jQuery(this).find('.bueno_acc .widget-title').append('<small>Good</small>');
			jQuery(this).find('.muybueno_lay .widget-title').append('<small>Excellent / Very Good</small>');
			jQuery(this).find('.excelente_acc .widget-title').append('<small>Excellent</small>');
		});
		/*
			 
			
			*/

		jQuery('img[usemap]').rwdImageMaps();
	});
