jQuery(document).ready(function($){
	var postTemplate = function( post ){
		return '<article class="hentry"><a href="#post-'+ post.ID +'">'+ post.post_title +'</a></article>';
	}
	var ajaxurl = "wp-admin/admin-ajax.php";
	$('#load-next-posts').on('click', function(){
		// la variable ajaxurl debe estar definida y apuntar a wp-admin/admin-ajax.php
		// en la data enviada con la petición, el parámetro "action" debe coincidir con la detección de la acción en PHP
		$.get( ajaxurl, {
			action: 'get_next_posts',
			offset: $('.hfeed').find('.hentry').length
		}, function(data){
			var q = data.length;
			if ( q > 0 ) {
				for ( var i = 0; i < q; i++ ){
					$('.hfeed').append( postTemplate(data[i]) );
				}
			} else {
				alert('Ya no hay más posts!')
			}
		}, 'json');
	});
});